@@ -5,4 +5,9 @@ class NumImports(BlueprintMetric):
     """ This class counts the blueprint's number of imports"""
 
     def count(self):
-        return len(self.blueprint.get('imports', []))
+
+        imports = self.blueprint.get('imports', [])
+        if type(imports) == list:
+            return len(imports)
+        elif type(imports) == dict:
+            return 1
