@@ -9,12 +9,14 @@ class BlueprintMetric:
         :param blueprint: a StringIO object representing the blueprint to parse
         """
         try:
+            self.__plain_blueprint = blueprint
             self.__blueprint = yaml.safe_load(blueprint)
+            if type(self.__blueprint) == list:
+                self.__blueprint = self.__blueprint[0]
+
             if self.__blueprint is None or len(self.__blueprint) == 0:
                 raise TypeError("Expected a non-empty blueprint")
 
-            self.__StringIOobject = blueprint
-
         except yaml.YAMLError:
             raise TypeError("Expected a valid YAML")
 
@@ -23,5 +25,5 @@ class BlueprintMetric:
         return self.__blueprint
 
     @property
-    def getStringIOobject(self):
-        return self.__StringIOobject
\ No newline at end of file
+    def plain_blueprint(self):
+        return self.__plain_blueprint
