@@ -9,9 +9,9 @@ class LinesComment(LinesCode):
     def count(self):
         cloc = 0
 
-        for l in self.blueprint.splitlines():
-            comment = re.search(r'#[\s\w\W]+', str(l.strip()))
-            if comment is not None:   
+        for line in self.blueprint.splitlines():
+            comment = re.search(r'#[\s\w\W]+', str(line.strip()))
+            if comment is not None:
                 cloc = cloc + 1
 
         return cloc
