@@ -1,5 +1,4 @@
 import re
-from io import StringIO
 from toscametrics.blueprint_metric import BlueprintMetric
 
 
@@ -8,13 +7,11 @@ class NumSuspiciousComments(BlueprintMetric):
 
     def count(self):
         """ Return the number of suspicious comments in the script. """
-        content = StringIO(self.getStringIOobject)
-
         suspicious = 0
 
-        for l in content.getvalue().splitlines():            
-            comment = re.search(r'#.+', str(l.strip()))
-            if comment is not None:   
+        for line in self.plain_blueprint.splitlines():
+            comment = re.search(r'#.+', str(line.strip()))
+            if comment is not None:
                 if re.search(r'TODO|FIXME|HACK|XXX|CHECKME|DOCME|TESTME|PENDING', comment.group()) is not None:
                     suspicious += 1
 
